#ifndef FIGHT_PLAYER_H
#define FIGHT_PLAYER_H

#include "state_machine.h"
#include "state.h"
#include "behaviour_entity.h"
#include "animation_sprite.h"
#include "input.h"
#include "vmath.h"
#include "transform.h"
#include "player_input.h"

extern const Vector PLAYER_SPEED;

typedef struct Player {
    Transform transform;
    
    PlayerInput* playerInput;
    
    Vector moveInput;
    int attackInput;
    
    Sprite* sprite;

    AnimationSprite* idle;
    AnimationSprite* walk;
    AnimationSprite* jab_a;
    AnimationSprite* jab_b;

    StateMachine* animationStateMachine;
    
    AnimationSprite* currentAnimation;
} Player;

Player* MakePlayer();
Player* SpawnPlayer(Vector location);
void DestroyPlayer(Player* self);

void PlayerHorizontalInput(Player* self, InputEvent value);
void PlayerVerticalInput(Player* self, InputEvent value);
void PlayerAttackInput(Player* self, InputEvent value);

void PlayerStart(Player* self);
void PlayerUpdate(Player* self, float deltaTime);
void PlayerDraw(Player* self);

impl_Drop_for(Player,
    DestroyPlayer
)

impl_BehaviourEntity_for(Player,
    PlayerStart,
    PlayerUpdate,
    PlayerDraw
)

#endif // !FIGHT_PLAYER_H
